import path from "path-browserify";
import { Buffer } from "buffer";
import { SPEC_URL, toHex } from "./util";
function isValidPointerInfo(val) {
    return val.oid.trim !== undefined && typeof val.size === "number";
}
export function readPointerInfo(content) {
    const info = content
        .toString()
        .trim()
        .split("\n")
        .reduce((accum, line) => {
        const [k, v] = line.split(" ", 2);
        if (k === "oid") {
            accum[k] = v.split(":", 2)[1];
        }
        else if (k === "size") {
            accum[k] = parseInt(v, 10);
        }
        return accum;
    }, {});
    if (isValidPointerInfo(info)) {
        return info;
    }
    else {
        throw new Error("LFS pointer is incomplete or cannot be read");
    }
}
export function readPointer({ dir, gitdir = path.join(dir, ".git"), content, }) {
    const info = readPointerInfo(content);
    const objectPath = path.join(gitdir, "lfs", "objects", info.oid.substr(0, 2), info.oid.substr(2, 2), info.oid);
    return { info, objectPath };
}
/** Formats given PointerInfo for writing in Git tree. */
export function formatPointerInfo(info) {
    const lines = [
        `version ${SPEC_URL}`,
        `oid sha256:${info.oid}`,
        `size ${info.size}`,
        "",
    ];
    return Buffer.from(lines.join("\n"));
}
export async function buildPointerInfo(content) {
    const size = content.byteLength;
    const hash = await crypto.subtle.digest("SHA-256", content);
    const oid = toHex(hash);
    return { oid, size };
}
//# sourceMappingURL=pointers.js.map